==> com.pocket_plan.j7_003_40_src.tar.gz: com.pocket_plan.j7_003_40_src.tar.gz/README.md <==
# PocketPlan
<img src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/app/src/main/res/mipmap-hdpi/ic_launcher.png" width="170"> 

PocketPlan is a lightweight, simplistic Android App designed to take care of everyday tasks such as managing a To-Do list, keeping notes, reminding you of upcoming birthdays and providing a self-sorting shopping list. It features both a light and a dark theme, and allows for a high degree of customizability of appearance and behavior in the settings menu.

All data, including the settings, can be exported as a local backup. PocketPlan natively supports the 6 languages English, German, French, Spanish, Russian and Italian.

Check out the [Contribution guidelines](https://github.com/estep248/PocketPlan/blob/master/CONTRIBUTING.md) if you would like to contribute to this project.

<a href="https://play.google.com/store/apps/details?id=com.pocket_plan.j7_003">
    <img alt="Get it on Google Play"
        height="80"
        src="https://play.google.com/intl/en_us/badges/images/generic/en_badge_web_generic.png"/>
</a>

<a href="https://f-droid.org/packages/com.pocket_plan.j7_003/">
    <img alt="Get it F-Droid"
        height="80"
        src="https://fdroid.gitlab.io/artwork/badge/get-it-on.png"/>
</a>

## Birthdays
Toggle reminders for individual birthdays or set custom reminders a couple days prior.
<div style="display:flex;">
<img alt="App image" src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/fastlane/metadata/android/en-US/images/phoneScreenshots/05.png" width="30%">
<img alt="App image" src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/fastlane/metadata/android/en-US/images/phoneScreenshots/01.png" width="30%">
</div>

## Notes
Organize your text based notes using folders and different colors.
<div style="display:flex;">
<img alt="App image" src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/fastlane/metadata/android/en-US/images/phoneScreenshots/06.png" width="30%">
<img alt="App image" src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/fastlane/metadata/android/en-US/images/phoneScreenshots/02.png" width="30%">
</div>

## Shopping
Items added to the shopping list will automatically be sorted into their respective category.
<div style="display:flex;">
<img alt="App image" src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/fastlane/metadata/android/en-US/images/phoneScreenshots/07.png" width="30%">
<img alt="App image" src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/fastlane/metadata/android/en-US/images/phoneScreenshots/03.png" width="30%">
</div>

## To-Do
Tasks are automatically sorted by priority ranging from high (red) to low (green).
<div style="display:flex;">
<img alt="App image" src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/fastlane/metadata/android/en-US/images/phoneScreenshots/08.png" width="30%">
<img alt="App image" src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/fastlane/metadata/android/en-US/images/phoneScreenshots/04.png" width="30%">
</div>

Screenshots from version 1.3.9 (39)

==> com.pocket_plan.j7_003_42_src.tar.gz: com.pocket_plan.j7_003_42_src.tar.gz/README.md <==
# PocketPlan
<img src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/app/src/main/res/mipmap-hdpi/ic_launcher.png" width="170"> 

PocketPlan is a lightweight, simplistic Android App designed to take care of everyday tasks such as managing a To-Do list, keeping notes, reminding you of upcoming birthdays and providing a self-sorting shopping list. It features both a light and a dark theme, and allows for a high degree of customizability of appearance and behavior in the settings menu.

All your data, including the settings, can be exported as a local backup. PocketPlan natively supports the 6 languages English, German, French, Spanish, Romanian, Russian and Italian.

Check out the [Contribution guidelines](https://github.com/estep248/PocketPlan/blob/master/CONTRIBUTING.md) if you would like to contribute to this project.

<a href="https://play.google.com/store/apps/details?id=com.pocket_plan.j7_003">
    <img alt="Get it on Google Play"
        height="80"
        src="https://play.google.com/intl/en_us/badges/images/generic/en_badge_web_generic.png"/>
</a>

<a href="https://f-droid.org/packages/com.pocket_plan.j7_003/">
    <img alt="Get it F-Droid"
        height="80"
        src="https://fdroid.gitlab.io/artwork/badge/get-it-on.png"/>
</a>

## Birthdays
Toggle reminders for individual birthdays or set custom reminders a couple days prior, e.g. to remember to buy a present.
<div style="display:flex;">
<img alt="App image" src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/fastlane/metadata/android/en-US/images/phoneScreenshots/01.png" width="30%">
<img alt="App image" src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/fastlane/metadata/android/en-US/images/phoneScreenshots/05.png" width="30%">
</div>

## Notes
Organize your text based notes using folders and different colors.
<div style="display:flex;">
<img alt="App image" src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/fastlane/metadata/android/en-US/images/phoneScreenshots/02.png" width="30%">
<img alt="App image" src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/fastlane/metadata/android/en-US/images/phoneScreenshots/06.png" width="30%">
</div>

## Shopping
Items added to the shopping list will automatically be sorted into their respective category.
<div style="display:flex;">
<img alt="App image" src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/fastlane/metadata/android/en-US/images/phoneScreenshots/03.png" width="30%">
<img alt="App image" src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/fastlane/metadata/android/en-US/images/phoneScreenshots/07.png" width="30%">
</div>

## To-Do
Tasks are automatically sorted by priority ranging from high (red) to low (green).
<div style="display:flex;">
<img alt="App image" src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/fastlane/metadata/android/en-US/images/phoneScreenshots/04.png" width="30%">
<img alt="App image" src="https://github.com/RayLeaf-Studios/PocketPlan/blob/master/fastlane/metadata/android/en-US/images/phoneScreenshots/08.png" width="30%">
</div>

Screenshots from version 1.3.9 (39)
